@@ -42,7 +42,7 @@ return [
     'people_list_account_upgrade_cta' => 'Jetzt upgraden',
     'people_list_untagged' => 'Unmarkierte Kontakte anzeigen',
     'people_list_filter_untag' => 'Es werden alle Kontakte ohne Tags angezeigt',
-    'archived_contact_readonly' => 'Archivierter Kontakt kann nicht bearbeitet werden, bitte zuerst dearchivieren.',
+    'archived_contact_readonly' => 'Archivierter Kontakt kann nicht bearbeitet werden, bitte zuerst entpacken.',
 
     // people add
     'people_add_title' => 'Person hinzufügen',
