@@ -7,60 +7,60 @@
  */
 
 return [
-    'sidebar_settings' => 'Account settings',
-    'sidebar_personalization' => 'Personalization',
-    'sidebar_settings_storage' => 'Storage',
-    'sidebar_settings_export' => 'Export data',
-    'sidebar_settings_users' => 'Users',
-    'sidebar_settings_subscriptions' => 'Subscription',
-    'sidebar_settings_import' => 'Import data',
-    'sidebar_settings_tags' => 'Tag management',
-    'sidebar_settings_api' => 'API',
-    'sidebar_settings_dav' => 'DAV Resources',
-    'sidebar_settings_security' => 'Security',
-    'sidebar_settings_auditlogs' => 'Audit logs',
+    'sidebar_settings' => 'Tilin asetukset',
+    'sidebar_personalization' => 'Mukauttaminen',
+    'sidebar_settings_storage' => 'Tallennustila',
+    'sidebar_settings_export' => 'Vie tiedot',
+    'sidebar_settings_users' => 'Käyttäjät',
+    'sidebar_settings_subscriptions' => 'Tilaus',
+    'sidebar_settings_import' => 'Tuo tiedot',
+    'sidebar_settings_tags' => 'Tagien hallinta',
+    'sidebar_settings_api' => 'Rajapinta / API',
+    'sidebar_settings_dav' => 'Dav- Resurssit',
+    'sidebar_settings_security' => 'Turvallisuus',
+    'sidebar_settings_auditlogs' => 'Tarkastuslokit',
 
-    'title_general' => 'General Information',
-    'title_i18n' => 'International settings',
-    'title_layout' => 'Layout',
+    'title_general' => 'Yleiset tiedot',
+    'title_i18n' => 'Kansainväliset asetukset',
+    'title_layout' => 'Ulkoasu',
 
-    'me_title' => 'Me as a contact',
-    'me_help' => 'This is the contact that represents <em>you</em> in Monica',
-    'me_select' => 'Select a contact',
-    'me_no_contact' => 'No contact selected yet.',
-    'me_select_click' => 'Click here to select a contact.',
-    'me_remove_contact' => 'Remove the association',
-    'me_choose' => 'Choose yourself',
-    'me_choose_placeholder' => 'Choose yourself',
+    'me_title' => 'Minä kontaktina',
+    'me_help' => 'Tämä on kontakti, joka edustaa <em>sinua</em> Monicassa',
+    'me_select' => 'Valitse yhteystieto',
+    'me_no_contact' => 'Yhteystietoa ei ole vielä valittu.',
+    'me_select_click' => 'Klikkaa tästä valitaksesi yhteystiedon.',
+    'me_remove_contact' => 'Poista tämä yhteys',
+    'me_choose' => 'Valitse itsesi',
+    'me_choose_placeholder' => 'Valitse itsesi',
 
-    'export_title' => 'Export your account data',
-    'export_be_patient' => 'Click the button to start the export. It might take several minutes to process the export – please be patient and do not spam the button.',
-    'export_title_sql' => 'Export to SQL',
-    'export_sql_explanation' => 'Exporting your data in SQL format allows you to take your data and import it to your own Monica instance. This is only valuable if you do have your own server.',
-    'export_sql_cta' => 'Export to SQL',
-    'export_sql_link_instructions' => 'Note: <a href=":url">read the instructions</a> to learn more about importing this file to your instance.',
-    'export_title_json' => 'Export to Json',
-    'export_submitted' => 'Your export has been submitted, it will be available in a few moment…',
-    'export_json_explanation' => 'Exporting your data in Json format for backup.',
-    'export_json_beta' => 'Json export is in preview mode. Tell us what you think about it:',
-    'export_json_cta' => 'Export to Json',
-    'export_header_type' => 'Type',
-    'export_header_timestamp' => 'Creation date',
-    'export_header_status' => 'Status',
-    'export_header_actions' => 'Actions',
-    'export_last_title' => 'Last exports',
-    'export_empty_title' => 'No exports yet',
-    'export_type_json' => 'Json export',
-    'export_type_sql' => 'SQL export',
-    'export_status_todo' => 'Submitted',
-    'export_status_doing' => 'Doing',
-    'export_status_done' => 'Done',
-    'export_status_failed' => 'Failed',
-    'export_not_done' => 'Download impossible, this export is not done yet.',
+    'export_title' => 'Vie tilisi tiedot',
+    'export_be_patient' => 'Napsauta painiketta aloittaaksesi viennin. Vienti voi kestää useita minuutteja – ole kärsivällinen ja älä spämmää nappia.',
+    'export_title_sql' => 'Vie SQL:ään',
+    'export_sql_explanation' => 'Viedään tietoja SQL-muodossa voit ottaa tiedot ja tuoda ne omaan Monica instance. Tämä on arvokasta vain, jos sinulla on oma palvelin.',
+    'export_sql_cta' => 'Vie SQL:ään',
+    'export_sql_link_instructions' => 'Huomautus: <a href=":url">lue ohjeet</a> saadaksesi lisätietoja tämän tiedoston tuonnista instanssiisi.',
+    'export_title_json' => 'Vie Jsoniin',
+    'export_submitted' => 'Vienti on lähetetty, se on saatavilla muutaman hetken kuluttua…',
+    'export_json_explanation' => 'Viedään tietojasi Jsonin muodossa varmuuskopiointia varten.',
+    'export_json_beta' => 'Jsonin vienti on esikatselutilassa. Kerro meille mitä mieltä olet siitä:',
+    'export_json_cta' => 'Vie Jsoniin',
+    'export_header_type' => 'Tyyppi',
+    'export_header_timestamp' => 'Luontipäivämäärä',
+    'export_header_status' => 'Tila',
+    'export_header_actions' => 'Toiminnot',
+    'export_last_title' => 'Viimeisin vienti',
+    'export_empty_title' => 'Ei vielä vientiä',
+    'export_type_json' => 'JSON:n vienti',
+    'export_type_sql' => 'SQL vienti',
+    'export_status_todo' => 'Lähetetty',
+    'export_status_doing' => 'Tehdään',
+    'export_status_done' => 'Valmis',
+    'export_status_failed' => 'Epäonnistui',
+    'export_not_done' => 'Lataus mahdotonta, tämä vienti ei ole vielä valmis.',
 
-    'firstname' => 'First name',
-    'lastname' => 'Last name',
-    'name_order' => 'Name order',
+    'firstname' => 'Etunimi',
+    'lastname' => 'Sukunimi',
+    'name_order' => 'Nimen järjestys',
     'name_order_firstname_lastname' => '<First name> <Last name> – John Doe',
     'name_order_lastname_firstname' => '<Last name> <First name> – Doe John',
     'name_order_firstname_lastname_nickname' => '<First name> <Last name> (<Nickname>) – John Doe (Rambo)',
@@ -112,27 +112,27 @@ return [
     'locale_nl' => 'Dutch',
     'locale_pt' => 'Portuguese',
     'locale_pt-BR' => 'Brazilian Portuguese',
-    'locale_ru' => 'Russian',
-    'locale_sv' => 'Swedish',
+    'locale_ru' => 'Venäjä',
+    'locale_sv' => 'Ruotsi',
     'locale_vi' => 'Vietnamese',
     'locale_zh' => 'Chinese Simplified',
     'locale_zh-TW' => 'Chinese Traditional',
     'locale_tr' => 'Turkish',
 
-    'security_title' => 'Security',
-    'security_help' => 'Change security matters for your account.',
-    'password_change' => 'Change your password',
-    'password_current' => 'Current password',
-    'password_current_placeholder' => 'Enter your current password',
-    'password_new1' => 'New password',
-    'password_new1_placeholder' => 'Enter your new password',
-    'password_new2' => 'Confirm your new password',
-    'password_new2_placeholder' => 'Retype your new password',
-    'password_btn' => 'Change password',
-    '2fa_title' => 'Two Factor Authentication',
+    'security_title' => 'Turvallisuus',
+    'security_help' => 'Muuta tilillesi liittyviä turvallisuuskysymyksiä.',
+    'password_change' => 'Vaihda salasanasi',
+    'password_current' => 'Nykyinen salasana',
+    'password_current_placeholder' => 'Anna nykyinen salasanasi',
+    'password_new1' => 'Uusi salasana',
+    'password_new1_placeholder' => 'Anna uusi salasana',
+    'password_new2' => 'Vahvista uusi salasana',
+    'password_new2_placeholder' => 'Kirjoita uusi salasanasi uudelleen',
+    'password_btn' => 'Vaihda salasana',
+    '2fa_title' => 'Kaksivaiheinen tunnistautuminen',
     '2fa_otp_title' => 'Two Factor Authentication mobile application',
-    '2fa_enable_title' => 'Enable Two Factor Authentication',
-    '2fa_enable_description' => 'Enable Two Factor Authentication to increase the security of your account.',
+    '2fa_enable_title' => 'Ota kaksivaiheinen tunnistautuminen käyttöön',
+    '2fa_enable_description' => 'Ota käyttöön kaksivaiheinen todennus lisätäksesi tilisi turvallisuutta.',
     '2fa_enable_otp' => 'Open up your Two Factor Authentication mobile app and scan the following QR barcode:',
     '2fa_enable_otp_help' => 'If your Two Factor Authentication mobile app does not support QR barcodes, enter in the following code:',
     '2fa_enable_otp_validate' => 'Please validate the new device you’ve just set up:',
@@ -146,12 +146,12 @@ return [
 
     'webauthn_title' => 'Security key — WebAuthn protocol',
     'webauthn_enable_description' => 'Add a new security key',
-    'webauthn_key_name_help' => 'Give your key a name.',
-    'webauthn_key_name' => 'Key name:',
-    'webauthn_success' => 'Your key is detected and validated.',
-    'webauthn_last_use' => 'Last use: {timestamp}',
-    'webauthn_delete_confirmation' => 'Are you sure you want to delete this key?',
-    'webauthn_delete_success' => 'Key deleted',
+    'webauthn_key_name_help' => 'Anna avaimellesi nimi.',
+    'webauthn_key_name' => 'Avaimen nimi:',
+    'webauthn_success' => 'Avaimesi on havaittu ja vahvistettu.',
+    'webauthn_last_use' => 'Viimeisin käyttö: {timestamp}',
+    'webauthn_delete_confirmation' => 'Oletko varma, että haluat poistaa tämän avaimen?',
+    'webauthn_delete_success' => 'Avain poistettu',
     'webauthn_insertKey' => 'Insert your security key.',
     'webauthn_buttonAdvise' => 'If your security key has a button, press it.',
     'webauthn_noButtonAdvise' => 'If it does not, remove it and insert it again.',
@@ -160,10 +160,10 @@ return [
     'webauthn_error_already_used' => 'This key is already registered. It’s not necessary to register it again.',
     'webauthn_error_not_allowed' => 'The operation either timed out or was not allowed.',
 
-    'recovery_title' => 'Recovery codes',
-    'recovery_show' => 'Get recovery codes',
-    'recovery_copy_help' => 'Copy codes in your clipboard',
-    'recovery_help_intro' => 'These are your recovery codes:',
+    'recovery_title' => 'Palautuskoodit',
+    'recovery_show' => 'Hanki palautuskoodit',
+    'recovery_copy_help' => 'Kopioi koodit leikepöydälle',
+    'recovery_help_intro' => 'Nämä ovat palautuskoodisi:',
     'recovery_help_information' => 'You can use each recovery code once.',
     'recovery_clipboard' => 'Codes copied to the clipboard.',
     'recovery_generate' => 'Generate new codes…',
@@ -190,14 +190,14 @@ return [
     'users_error_please_confirm' => 'Please confirm that you want to invite this user before proceeding with the invitation',
     'users_error_email_already_taken' => 'This email is already taken. Please choose another one',
     'users_error_already_invited' => 'You already have invited this user. Please choose another email address.',
-    'users_error_email_not_similar' => 'This is not the email of the person who’ve invited you.',
-    'users_invitation_deleted_confirmation_message' => 'The invitation has been successfully deleted',
-    'users_invitations_delete_confirmation' => 'Are you sure you want to delete this invitation?',
-    'users_list_delete_confirmation' => 'Are you sure to delete this user from your account?',
-    'users_invitation_need_subscription' => 'Adding more users requires a subscription.',
+    'users_error_email_not_similar' => 'Tämä ei ole sen henkilön sähköposti, joka on kutsunut sinut.',
+    'users_invitation_deleted_confirmation_message' => 'Kutsu on poistettu onnistuneesti',
+    'users_invitations_delete_confirmation' => 'Haluatko varmasti poistaa tämän kutsun?',
+    'users_list_delete_confirmation' => 'Haluatko varmasti poistaa tämän käyttäjän tililtäsi?',
+    'users_invitation_need_subscription' => 'Useampien käyttäjien lisääminen vaatii tilauksen.',
 
-    'subscriptions_account_current_plan' => 'Your current plan',
-    'subscriptions_account_current_legacy' => 'Current plan, not selectable anymore:',
+    'subscriptions_account_current_plan' => 'Nykyinen tilauksesi',
+    'subscriptions_account_current_legacy' => 'Nykyinen suunnitelma, ei enää valittavissa:',
     'subscriptions_account_current_paid_plan' => 'You are on the :name plan. Thanks so much for being a subscriber.',
 
     'subscriptions_account_next_billing_title' => 'Next bill',
@@ -221,28 +221,28 @@ return [
     'subscriptions_account_update_title' => 'Update Monica subscription',
     'subscriptions_account_update_description' => 'You can change your subscription’s frequency here.',
     'subscriptions_account_update_information' => 'You will be billed immediately for the new amount. Your subscription will extend to the new period, depending on your choice.',
-    'subscriptions_account_invoices' => 'Invoices',
-    'subscriptions_account_invoices_download' => 'Download',
-    'subscriptions_account_invoices_subscription' => 'Subscription from :startDate to :endDate',
-    'subscriptions_account_payment' => 'Which payment option fits you best?',
-    'subscriptions_account_confirm_payment' => 'Your payment is currently incomplete, please <a href=":url">confirm your payment</a>.',
-    'subscriptions_downgrade_title' => 'Downgrade your account to the free plan',
-    'subscriptions_downgrade_limitations' => 'The free plan has limitations. In order to be able to downgrade, you need to pass the checklist below:',
-    'subscriptions_downgrade_rule_users' => 'You must have only 1 user in your account',
-    'subscriptions_downgrade_rule_users_constraint' => 'You currently have <a href=":url">1 user</a> in your account.|You currently have <a href=":url">:count users</a> in your account.',
-    'subscriptions_downgrade_rule_invitations' => 'You must not have any pending invitations',
-    'subscriptions_downgrade_rule_invitations_constraint' => 'You currently have <a href=":url">1 pending invitation</a>.|You currently have <a href=":url">:count pending invitations</a>.',
-    'subscriptions_downgrade_rule_contacts' => 'You must not have more than :number active contacts',
-    'subscriptions_downgrade_rule_contacts_constraint' => 'You currently have <a href=":url">1 contact</a>.|You currently have <a href=":url">:count contacts</a>.',
-    'subscriptions_downgrade_rule_contacts_archive' => 'We can also <a href=":url">archive all your contacts for you</a> – that would clear this rule and let you proceed with your account’s downgrade process.',
-    'subscriptions_downgrade_cta' => 'Downgrade',
-    'subscriptions_downgrade_success' => 'You are back to the Free plan!',
-    'subscriptions_downgrade_thanks' => 'Thanks so much for trying the paid plan. We keep adding new features on Monica all the time – so you might want to come back in the future to see if you might be interested in taking a subscription again.',
-    'subscriptions_back' => 'Back to settings',
-    'subscriptions_upgrade_title' => 'Upgrade your account',
-    'subscriptions_upgrade_choose' => 'You picked the :plan plan.',
-    'subscriptions_upgrade_infos' => 'We couldn’t be happier. Enter your payment info below.',
-    'subscriptions_upgrade_name' => 'Name on card',
+    'subscriptions_account_invoices' => 'Laskut',
+    'subscriptions_account_invoices_download' => 'Lataa',
+    'subscriptions_account_invoices_subscription' => 'Tilaus :startDate päivään :endDate',
+    'subscriptions_account_payment' => 'Mikä maksuvaihtoehto sopii sinulle parhaiten?',
+    'subscriptions_account_confirm_payment' => 'Maksu on tällä hetkellä kesken, ole hyvä <a href=":url">vahvista maksusi</a>.',
+    'subscriptions_downgrade_title' => 'Alenna tilisi maksuttomaan tilaukseen',
+    'subscriptions_downgrade_limitations' => 'Ilmaisessa versiossa on rajoituksia. Jotta voit alentaa tilisi, sinun täytyy läpäistä tarkistuslista alla:',
+    'subscriptions_downgrade_rule_users' => 'Sinulla tulee olla vain 1 käyttäjä tililläsi',
+    'subscriptions_downgrade_rule_users_constraint' => 'Sinulla on tällä hetkellä <a href=":url">1 käyttäjä</a> tililläsi. Sinulla on tällä hetkellä <a href=":url">:count käyttäjiä</a> tililläsi.',
+    'subscriptions_downgrade_rule_invitations' => 'Sinulla ei saa olla odottavia kutsuja',
+    'subscriptions_downgrade_rule_invitations_constraint' => 'Sinulla on <a href=":url">1 odottava kutsu</a>. Olet tällä hetkellä <a href=":url">:count odottavia kutsuja</a>.',
+    'subscriptions_downgrade_rule_contacts' => 'Sinulla ei saa olla enempää kuin :number aktiivisia yhteystietoja',
+    'subscriptions_downgrade_rule_contacts_constraint' => 'Sinulla on tällä hetkellä <a href=":url">1 yhteystieto</a>.| Sinulla on tällä hetkellä <a href=":url">:count yhteystietoja</a>.',
+    'subscriptions_downgrade_rule_contacts_archive' => 'Voimme myös <a href=":url">arkistoida kaikki yhteystietosi sinua varten</a> – se poistaisi tämän säännön ja antaa sinun jatkaa tilisi ilmaisversioon siirtymis prosessia.',
+    'subscriptions_downgrade_cta' => 'Alenna tasoa',
+    'subscriptions_downgrade_success' => 'Olet palannut takaisin ilmaiseen versioon!',
+    'subscriptions_downgrade_thanks' => 'Kiitos tosi paljon kun koitit maksullista versioa. Me lisäämme uusia ominaisuuksia Monicaan kokoajan, joten voit haluta palata takaisin maksullisen version käyttäjäksi.',
+    'subscriptions_back' => 'Takaisin asetuksiin',
+    'subscriptions_upgrade_title' => 'Päivitä tilisi',
+    'subscriptions_upgrade_choose' => 'Valitsitte :plan suunnitelman.',
+    'subscriptions_upgrade_infos' => 'Emme voisi olla tyytyväisempiä. Syötä maksutietosi alla.',
+    'subscriptions_upgrade_name' => 'Nimi kortissa',
     'subscriptions_upgrade_zip' => 'ZIP or postal code',
     'subscriptions_upgrade_credit' => 'Credit or debit card',
     'subscriptions_upgrade_submit' => 'Pay {amount}',
@@ -275,7 +275,7 @@ return [
     'subscriptions_help_opensource_title' => 'What is an open source project?',
     'subscriptions_help_opensource_desc' => 'Monica is an open source project.  This means it is built by a community who wants to build a great tool for the greater good. Being open source means the code is publicly available on GitHub, and everyone can inspect it, modify it or enhance it. All the money we raise is dedicated to building better features, paying for more powerful servers, and paying other costs. Thanks for your help. We couldn’t do it without you.',
     'subscriptions_help_limits_title' => 'Is there a limit to the number of contacts we can have on the free plan?',
-    'subscriptions_help_limits_plan' => 'Yes. Free plans let you manage :number contacts.',
+    'subscriptions_help_limits_plan' => 'Kyllä. Ilmaisen version avulla voit hallita :number yhteystietoja.',
     'subscriptions_help_discounts_title' => 'Do you have discounts for non-profits and education?',
     'subscriptions_help_discounts_desc' => 'We do! Monica is free for students, and free for non-profits and charities. Just contact <a href=":support">the support</a> with a proof of your status and we’ll apply this special status in your account.',
     'subscriptions_help_change_title' => 'What if I change my mind?',
@@ -318,14 +318,14 @@ return [
     'import_vcard_parse_error' => 'Error when parsing the vCard entry',
     'import_vcard_contact_exist' => 'Contact already exists',
     'import_vcard_contact_no_firstname' => 'No first name (mandatory)',
-    'import_vcard_file_not_found' => 'File not found',
-    'import_vcard_unknown_entry' => 'Unknown contact name',
-    'import_vcard_file_no_entries' => 'File contains no entries',
-    'import_blank_title' => 'You haven’t imported any contacts yet.',
-    'import_blank_question' => 'Would you like to import contacts now?',
-    'import_blank_description' => 'We can import vCard files that you can get from Google Contacts or your Contact manager.',
-    'import_blank_cta' => 'Import vCard',
-    'import_need_subscription' => 'Importing data requires a subscription.',
+    'import_vcard_file_not_found' => 'Tiedostoa ei löydy',
+    'import_vcard_unknown_entry' => 'Tuntematon yhteystiedon nimi',
+    'import_vcard_file_no_entries' => 'Tiedosto ei sisällä tietueita',
+    'import_blank_title' => 'Et ole vielä tuonut yhtään yhteystietoa.',
+    'import_blank_question' => 'Haluatko tuoda yhteystietoja nyt?',
+    'import_blank_description' => 'Voimme tuoda vCard-tiedostoja, joita voit saada Googlen yhteystiedoista tai yhteystietojen hallinnasta.',
+    'import_blank_cta' => 'Tuo vCard-yhteystietoja',
+    'import_need_subscription' => 'Tietojen tuominen vaatii tilauksen.',
 
     'tags_list_title' => 'Tags',
     'tags_list_description' => 'You can organize your contacts by setting up tags. Tags work like folders, but you can add more than one tag to a contact. To add a new tag, add it on the contact itself.',
@@ -337,30 +337,30 @@ return [
 
     'api_title' => 'API access',
     'api_description' => 'The API can be used to manipulate Monica’s data from an external application, like a mobile application for instance.',
-    'api_help' => 'To use the API, a token is mandatory. You can either create a personal access token (Bearer authentication), or authorize an OAuth client to create it for you. See <a href=":url">API documentation</a>.',
-    'api_endpoint' => 'The API endpoint for this Monica instance is:',
+    'api_help' => 'API:n käyttä vaatii tokenin. Voit joko luoda henkilökohtaisen tokenin (Bearer authenication) tai valtuuttaa OAuth asiakkaan luoda sen sinulle.  Katso <a href=":url">API-dokumentaatio</a>.',
+    'api_endpoint' => 'Tämän Monica instanssin API osoite on:',
 
-    'api_personal_access_tokens' => 'Personal access tokens',
+    'api_personal_access_tokens' => 'Henkilökohtaiset pääsymerkit',
     'api_pao_description' => 'Make sure you give this token to a source you trust – as they allow you to access all your data.',
     'api_token_title' => 'Personal Access Tokens',
-    'api_token_create_new' => 'Create New Token',
+    'api_token_create_new' => 'Luo uusi API-valtuustunnus',
     'api_token_not_created' => 'You have not created any personal access tokens.',
     'api_token_name' => 'Token name',
     'api_token_expire' => 'Expires at {date}',
-    'api_token_delete' => 'Delete',
+    'api_token_delete' => 'Poista',
     'api_token_create' => 'Create Token',
-    'api_token_scopes' => 'Scopes',
-    'api_token_help' => 'Here is your new personal access token. This is the only time it will be shown so don’t lose it! You may now use this token to make API requests.',
+    'api_token_scopes' => 'Soveltamisalueet',
+    'api_token_help' => 'Tässä on uusi henkilökohtainen pääsytunnus. Tämä on ainoa kerta kuin se näytetään joten älä menetä sitä! Voit nyt käyttää tätä tunnusta API pyyntöjen tekemiseen.',
 
-    'api_oauth_clients' => 'Your OAuth clients',
-    'api_oauth_clients_desc' => 'This section lets you register your own OAuth clients.',
-    'api_oauth_clients_desc2' => 'Use this client id to request a new token, and convert authorization codes to access tokens. See <a href="{url}">Laravel Passport documentation</a> for more information.',
-    'api_oauth_title' => 'OAuth Clients',
-    'api_oauth_create_new' => 'Create New Client',
-    'api_oauth_edit' => 'Edit Client',
-    'api_oauth_not_created' => 'You have not created any OAuth clients.',
+    'api_oauth_clients' => 'OAuth asiakkaasi',
+    'api_oauth_clients_desc' => 'Tämän osion avulla voit rekisteröidä omia OAuth asiakkaita.',
+    'api_oauth_clients_desc2' => 'Käytä tätä asiakastunnusta uuden tunnuksen pyytämiseen ja muunna valtuutuskoodit poletteihin. Katso <a href="{url}">Laravel Passport dokumentaatio</a> saadaksesi lisätietoja.',
+    'api_oauth_title' => 'OAuth Asiakkaat',
+    'api_oauth_create_new' => 'Luo Uusi Asiakas',
+    'api_oauth_edit' => 'Muokkaa Asiakasta',
+    'api_oauth_not_created' => 'Et ole luonut yhtään OAuth-asiakasta.',
     'api_oauth_clientid' => 'Client ID',
-    'api_oauth_name' => 'Name',
+    'api_oauth_name' => 'Nimi',
     'api_oauth_name_help' => 'Something your users will recognize and trust.',
     'api_oauth_secret' => 'Secret',
     'api_oauth_create' => 'Create Client',
