@@ -140,162 +140,192 @@ return [
 
     'relationship_type_partner' => 'בן זוג',
     'relationship_type_partner_female' => 'בת זוג',
+    'relationship_type_partner_male' => 'בזוגיות עם',
     'relationship_type_partner_with_name' => 'בן הזוג של :name',
     'relationship_type_partner_female_with_name' => 'בת הזוג של :name',
+    'relationship_type_partner_male_with_name' => 'הזוגיות של :name',
 
     'relationship_type_spouse' => 'בעל',
-    'relationship_type_spouse_female' => 'wife',
-    'relationship_type_spouse_male' => 'husband',
+    'relationship_type_spouse_female' => 'אישה',
+    'relationship_type_spouse_male' => 'בעל',
     'relationship_type_spouse_with_name' => 'בעלה של :name',
-    'relationship_type_spouse_female_with_name' => ':name’s wife',
-    'relationship_type_spouse_male_with_name' => ':name’s husband',
+    'relationship_type_spouse_female_with_name' => 'אשתו של :name',
+    'relationship_type_spouse_male_with_name' => 'בעלה של :name',
 
     'relationship_type_date' => 'ליציאה',
     'relationship_type_date_female' => 'יוצאת קבוע',
+    'relationship_type_date_male' => 'דייט',
     'relationship_type_date_with_name' => 'יוצא קבוע עם :name',
     'relationship_type_date_female_with_name' => 'יוצאת קבוע עם :name',
+    'relationship_type_date_male_with_name' => 'הדייט של :name',
 
     'relationship_type_lover' => 'מאהב',
     'relationship_type_lover_female' => 'מאהבת',
+    'relationship_type_lover_male' => 'מאהב',
     'relationship_type_lover_with_name' => 'מאהב של :name',
     'relationship_type_lover_female_with_name' => 'מאהבת של :name',
+    'relationship_type_lover_male_with_name' => 'המאהב של :name',
 
     'relationship_type_inlovewith' => 'מאוהב',
     'relationship_type_inlovewith_female' => 'מאוהבת',
+    'relationship_type_inlovewith_male' => 'מאוהב',
     'relationship_type_inlovewith_with_name' => 'מושא אהבתו של :name',
     'relationship_type_inlovewith_female_with_name' => 'מושא אהבתה של :name',
+    'relationship_type_inlovewith_male_with_name' => 'מישהו ש־:name מאוהבת בו',
 
     'relationship_type_lovedby' => 'נאהב על ידי',
     'relationship_type_lovedby_female' => 'נאהבת על ידי',
+    'relationship_type_lovedby_male' => 'נאהב על ידי',
     'relationship_type_lovedby_with_name' => 'מאהב סודי של :name',
     'relationship_type_lovedby_female_with_name' => 'מאהבת סודית של :name',
+    'relationship_type_lovedby_male_with_name' => 'מאהב סודי של :name',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'חברה לשעבר',
-    'relationship_type_ex_male' => 'ex-boyfriend',
+    'relationship_type_ex_male' => 'חבר לשעבר',
     'relationship_type_ex_with_name' => ':name’s ex-partner',
     'relationship_type_ex_female_with_name' => 'חברה לשעבר של :name',
-    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',
+    'relationship_type_ex_male_with_name' => 'חבר לשעבר של :name',
 
-    'relationship_type_parent' => 'parent',
+    'relationship_type_parent' => 'הורה',
     'relationship_type_parent_female' => 'אימא',
-    'relationship_type_parent_male' => 'father',
-    'relationship_type_parent_with_name' => ':name’s parent',
+    'relationship_type_parent_male' => 'אבא',
+    'relationship_type_parent_with_name' => 'הורה של :name',
     'relationship_type_parent_female_with_name' => 'אימא של :name',
-    'relationship_type_parent_male_with_name' => ':name’s father',
+    'relationship_type_parent_male_with_name' => 'אבא של :name',
 
-    'relationship_type_child' => 'child',
+    'relationship_type_child' => 'ילד',
     'relationship_type_child_female' => 'בת',
-    'relationship_type_child_male' => 'son',
-    'relationship_type_child_with_name' => ':name’s child',
+    'relationship_type_child_male' => 'בן',
+    'relationship_type_child_with_name' => 'הילד של :name',
     'relationship_type_child_female_with_name' => 'בת של :name',
-    'relationship_type_child_male_with_name' => ':name’s son',
+    'relationship_type_child_male_with_name' => 'בן של :name',
 
-    'relationship_type_stepparent' => 'step-parent',
+    'relationship_type_stepparent' => 'הורה חורג',
     'relationship_type_stepparent_female' => 'אם חורגת',
-    'relationship_type_stepparent_male' => 'stepfather',
-    'relationship_type_stepparent_with_name' => ':name’s step-parent',
+    'relationship_type_stepparent_male' => 'אב חורג',
+    'relationship_type_stepparent_with_name' => 'הורה חורג של :name',
     'relationship_type_stepparent_female_with_name' => 'אם חורגת של :name',
-    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',
+    'relationship_type_stepparent_male_with_name' => 'אב חורג של :name',
 
-    'relationship_type_stepchild' => 'stepchild',
+    'relationship_type_stepchild' => 'ילד חורג',
     'relationship_type_stepchild_female' => 'בת חורגת',
-    'relationship_type_stepchild_male' => 'stepson',
-    'relationship_type_stepchild_with_name' => ':name’s stepchild',
+    'relationship_type_stepchild_male' => 'בן חורג',
+    'relationship_type_stepchild_with_name' => 'הילד החורג של :name',
     'relationship_type_stepchild_female_with_name' => 'בת חורגת של :name',
-    'relationship_type_stepchild_male_with_name' => ':name’s stepson',
+    'relationship_type_stepchild_male_with_name' => 'בן חורג של :name',
 
-    'relationship_type_sibling' => 'sibling',
+    'relationship_type_sibling' => 'אחאי',
     'relationship_type_sibling_female' => 'אחות',
-    'relationship_type_sibling_male' => 'brother',
-    'relationship_type_sibling_with_name' => ':name’s sibling',
+    'relationship_type_sibling_male' => 'אח',
+    'relationship_type_sibling_with_name' => 'אחאי של :name',
     'relationship_type_sibling_female_with_name' => 'אחות של :name',
-    'relationship_type_sibling_male_with_name' => ':name’s brother',
+    'relationship_type_sibling_male_with_name' => 'אח של :name',
 
     'relationship_type_grandparent' => 'grandparent',
-    'relationship_type_grandparent_female' => 'grandmother',
-    'relationship_type_grandparent_male' => 'grandfather',
+    'relationship_type_grandparent_female' => 'סבתא',
+    'relationship_type_grandparent_male' => 'סבא',
     'relationship_type_grandparent_with_name' => ':name’s grandparent',
-    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
-    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',
+    'relationship_type_grandparent_female_with_name' => 'סבתא של :name',
+    'relationship_type_grandparent_male_with_name' => 'סבא של :name',
 
-    'relationship_type_grandchild' => 'grandchild',
-    'relationship_type_grandchild_female' => 'granddaughter',
-    'relationship_type_grandchild_male' => 'grandson',
+    'relationship_type_grandchild' => 'נכד/ה',
+    'relationship_type_grandchild_female' => 'נכדה',
+    'relationship_type_grandchild_male' => 'נכד',
     'relationship_type_grandchild_with_name' => ':name’s grandchild',
-    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
-    'relationship_type_grandchild_male_with_name' => ':name’s grandson',
+    'relationship_type_grandchild_female_with_name' => 'נכדה של :name',
+    'relationship_type_grandchild_male_with_name' => 'נכד של :name',
 
     'relationship_type_uncle' => 'דוד',
     'relationship_type_uncle_female' => 'דודה',
+    'relationship_type_uncle_male' => 'דוד',
     'relationship_type_uncle_with_name' => 'דוד של :name',
     'relationship_type_uncle_female_with_name' => 'דודה של :name',
+    'relationship_type_uncle_male_with_name' => 'דוד של :name',
 
     'relationship_type_nephew' => 'אחיין',
     'relationship_type_nephew_female' => 'אחיינית',
+    'relationship_type_nephew_male' => 'אחיין',
     'relationship_type_nephew_with_name' => 'אחיין של :name',
     'relationship_type_nephew_female_with_name' => 'אחיינית של :name',
+    'relationship_type_nephew_male_with_name' => 'אחיין של :name',
 
     'relationship_type_cousin' => 'בן דוד',
     'relationship_type_cousin_female' => 'בת דודה',
+    'relationship_type_cousin_male' => 'בן דוד',
     'relationship_type_cousin_with_name' => 'בן דוד של :name',
     'relationship_type_cousin_female_with_name' => 'בת דודה של :name',
+    'relationship_type_cousin_male_with_name' => 'בן דוד של :name',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => 'סנדקית',
-    'relationship_type_godfather_male' => 'godfather',
+    'relationship_type_godfather_male' => 'סנדק',
     'relationship_type_godfather_with_name' => ':name’s godparent',
     'relationship_type_godfather_female_with_name' => 'הסנדקית של :name',
-    'relationship_type_godfather_male_with_name' => ':name’s godfather',
+    'relationship_type_godfather_male_with_name' => 'הסנדק של :name',
 
     'relationship_type_godson' => 'godchild',
     'relationship_type_godson_female' => 'בת סנדקות',
-    'relationship_type_godson_male' => 'godson',
+    'relationship_type_godson_male' => 'בן סנדקות',
     'relationship_type_godson_with_name' => ':name’s godchild',
     'relationship_type_godson_female_with_name' => 'בת הסנדקות של :name',
-    'relationship_type_godson_male_with_name' => ':name’s godson',
+    'relationship_type_godson_male_with_name' => 'בן הסנדקות של :name',
 
     'relationship_type_friend' => 'חבר',
     'relationship_type_friend_female' => 'חברה',
+    'relationship_type_friend_male' => 'חבר',
     'relationship_type_friend_with_name' => 'חבר של :name',
     'relationship_type_friend_female_with_name' => 'חברה של :name',
+    'relationship_type_friend_male_with_name' => 'חבר של :name',
 
     'relationship_type_bestfriend' => 'החבר הטוב ביותר',
     'relationship_type_bestfriend_female' => 'החברה הטובה ביותר',
+    'relationship_type_bestfriend_male' => 'החבר הטוב ביותר',
     'relationship_type_bestfriend_with_name' => 'החבר הכי טוב של :name',
     'relationship_type_bestfriend_female_with_name' => 'החברה הכי טובה של :name',
+    'relationship_type_bestfriend_male_with_name' => 'החבר הכי טוב של :name',
 
     'relationship_type_colleague' => 'עמית לעבודה',
     'relationship_type_colleague_female' => 'עמיתה לעבודה',
+    'relationship_type_colleague_male' => 'עמית לעבודה',
     'relationship_type_colleague_with_name' => 'עמית לעבודה של :name',
     'relationship_type_colleague_female_with_name' => 'עמיתה לעבודה של :name',
+    'relationship_type_colleague_male_with_name' => 'עמית לעבודה של :name',
 
     'relationship_type_boss' => 'מנהל',
     'relationship_type_boss_female' => 'מנהלת',
+    'relationship_type_boss_male' => 'מנהל',
     'relationship_type_boss_with_name' => 'מנהל של :name',
     'relationship_type_boss_female_with_name' => 'מנהלת של :name',
+    'relationship_type_boss_male_with_name' => 'מנהל של :name',
 
     'relationship_type_subordinate' => 'כפוף',
     'relationship_type_subordinate_female' => 'כפופה',
+    'relationship_type_subordinate_male' => 'כפוף',
     'relationship_type_subordinate_with_name' => 'כפוף ל:name',
     'relationship_type_subordinate_female_with_name' => 'כפופה ל:name',
+    'relationship_type_subordinate_male_with_name' => 'כפוף ל:name',
 
     'relationship_type_mentor' => 'חונך',
     'relationship_type_mentor_female' => 'חונכת',
+    'relationship_type_mentor_male' => 'חונך',
     'relationship_type_mentor_with_name' => 'חונך של :name',
     'relationship_type_mentor_female_with_name' => 'חונך של :name',
+    'relationship_type_mentor_male_with_name' => 'חונך של :name',
 
     'relationship_type_protege' => 'protégé',
-    'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_female' => 'חניכה',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
-    'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_female_with_name' => 'חניכה של :name',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => 'גרושה',
-    'relationship_type_ex_husband_male' => 'ex-husband',
+    'relationship_type_ex_husband_male' => 'גרוש',
     'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
     'relationship_type_ex_husband_female_with_name' => 'הגרושה של :name',
-    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',
+    'relationship_type_ex_husband_male_with_name' => 'הגרוש של :name',
 
     // emotions
     'emotion_primary_love' => 'אהבה',
@@ -465,19 +495,19 @@ return [
     'emotion_dread' => 'מורא',
 
     // weather
-    'weather_sunny' => 'Sunny',
-    'weather_clear' => 'Clear',
-    'weather_clear-day' => 'Clear',
+    'weather_sunny' => 'שמשי',
+    'weather_clear' => 'בהיר',
+    'weather_clear-day' => 'בהיר',
     'weather_clear-night' => 'לילה בהיר',
-    'weather_light-drizzle' => 'Light drizzle',
+    'weather_light-drizzle' => 'טפטוף קל',
     'weather_patchy-light-drizzle' => 'Patchy light drizzle',
     'weather_patchy-light-rain' => 'Patchy light rain',
-    'weather_light-rain' => 'Light rain',
+    'weather_light-rain' => 'גשם קל',
     'weather_moderate-rain-at-times' => 'Moderate rain at times',
     'weather_moderate-rain' => 'Moderate rain',
     'weather_patchy-rain-possible' => 'Patchy rain possible',
-    'weather_heavy-rain-at-times' => 'Heavy rain at times',
-    'weather_heavy-rain' => 'Heavy rain',
+    'weather_heavy-rain-at-times' => 'גשם כבד במקטעים',
+    'weather_heavy-rain' => 'גשם כבד',
     'weather_light-freezing-rain' => 'Light freezing rain',
     'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
     'weather_light-sleet' => 'Light sleet',
@@ -486,14 +516,14 @@ return [
     'weather_torrential-rain-shower' => 'Torrential rain shower',
     'weather_rain' => 'גשם',
     'weather_snow' => 'שלג',
-    'weather_blowing-snow' => 'Blowing snow',
+    'weather_blowing-snow' => 'משבי שלג',
     'weather_patchy-light-snow' => 'Patchy light snow',
-    'weather_light-snow' => 'Light snow',
+    'weather_light-snow' => 'שלג קל',
     'weather_patchy-moderate-snow' => 'Patchy moderate snow',
-    'weather_moderate-snow' => 'Moderate snow',
+    'weather_moderate-snow' => 'שלג מתון',
     'weather_patchy-heavy-snow' => 'Patchy heavy snow',
-    'weather_heavy-snow' => 'Heavy snow',
-    'weather_light-snow-showers' => 'Light snow showers',
+    'weather_heavy-snow' => 'שלג כבד',
+    'weather_light-snow-showers' => 'ממטרי שלג קלים',
     'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
     'weather_patchy-snow-possible' => 'Patchy snow possible',
     'weather_patchy-sleet-possible' => 'Patchy sleet possible',
@@ -504,13 +534,13 @@ return [
     'weather_wind' => 'רוח',
     'weather_fog' => 'ערפל',
     'weather_freezing-fog' => 'Freezing fog',
-    'weather_mist' => 'Mist',
-    'weather_blizzard' => 'Blizzard',
-    'weather_overcast' => 'Overcast',
+    'weather_mist' => 'ערפל',
+    'weather_blizzard' => 'סופת שלג',
+    'weather_overcast' => 'קודר',
     'weather_cloudy' => 'מעונן',
-    'weather_partly-cloudy-day' => 'Partly cloudy',
-    'weather_partly-cloudy-night' => 'Partly cloudy',
-    'weather_freezing-drizzle' => 'Freezing drizzle',
+    'weather_partly-cloudy-day' => 'מעונן חלקית',
+    'weather_partly-cloudy-night' => 'מעונן חלקית',
+    'weather_freezing-drizzle' => 'טפטוף קפוא',
     'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
     'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
     'weather_ice-pellets' => 'Ice pellets',
