@@ -34,29 +34,29 @@ return [
     'me_choose_placeholder' => 'בחירה עצמית',
 
     'export_title' => 'יצוא נתוני החשבון שלך',
-    'export_be_patient' => 'Click the button to start the export. It might take several minutes to process the export – please be patient and do not spam the button.',
-    'export_title_sql' => 'Export to SQL',
-    'export_sql_explanation' => 'Exporting your data in SQL format allows you to take your data and import it to your own Monica instance. This is only valuable if you do have your own server.',
-    'export_sql_cta' => 'Export to SQL',
-    'export_sql_link_instructions' => 'Note: <a href=":url">read the instructions</a> to learn more about importing this file to your instance.',
-    'export_title_json' => 'Export to Json',
-    'export_submitted' => 'Your export has been submitted, it will be available in a few moment…',
-    'export_json_explanation' => 'Exporting your data in Json format for backup.',
+    'export_be_patient' => 'יש ללחוץ על הכפתור כדי להתחיל את הייצוא. עיבוד הייצוא עשוי לארוך מספר דקות - נא להתאזר בסבלנות ולא ללחוץ על הכפתור שוב.',
+    'export_title_sql' => 'ייצוא ל־SQL',
+    'export_sql_explanation' => 'יצוא הנתונים שלך במבנה SQL מאפשר לך לקחת את הנתונים שלך ולייבא אותם לעותק של מוניקה משלך. לתכונה זו יש ערך רק אם יש לך שרת משלך.',
+    'export_sql_cta' => 'ייצוא ל־SQL',
+    'export_sql_link_instructions' => 'לתשומת לבך: ניתן <a href=":url">לקרוא את ההנחיות</a> כדי ללמוד יותר על יבוא הקובץ הזה לעותק שלך.',
+    'export_title_json' => 'ייצוא ל־Json',
+    'export_submitted' => 'הייצוא שלך הוגש, הוא יהיה זמין בעוד מספר רגעים…',
+    'export_json_explanation' => 'הנתונים שלך מיוצאים בתצורת Json למטרות גיבוי.',
     'export_json_beta' => 'Json export is in preview mode. Tell us what you think about it:',
-    'export_json_cta' => 'Export to Json',
-    'export_header_type' => 'Type',
-    'export_header_timestamp' => 'Creation date',
-    'export_header_status' => 'Status',
-    'export_header_actions' => 'Actions',
+    'export_json_cta' => 'ייצוא ל־Json',
+    'export_header_type' => 'סוג',
+    'export_header_timestamp' => 'מועד יצירה',
+    'export_header_status' => 'מצב',
+    'export_header_actions' => 'פעולות',
     'export_last_title' => 'Last exports',
-    'export_empty_title' => 'No exports yet',
-    'export_type_json' => 'Json export',
-    'export_type_sql' => 'SQL export',
-    'export_status_todo' => 'Submitted',
-    'export_status_doing' => 'Doing',
-    'export_status_done' => 'Done',
-    'export_status_failed' => 'Failed',
-    'export_not_done' => 'Download impossible, this export is not done yet.',
+    'export_empty_title' => 'אין נתונים שיוצאו עדיין',
+    'export_type_json' => 'ייצוא Json',
+    'export_type_sql' => 'ייצוא SQL',
+    'export_status_todo' => 'הוגש',
+    'export_status_doing' => 'מתבצע',
+    'export_status_done' => 'בוצע',
+    'export_status_failed' => 'נכשל',
+    'export_not_done' => 'אי אפשר להוריד, הייצוא עדיין לא בוצע.',
 
     'firstname' => 'שם פרטי',
     'lastname' => 'שם משפחה',
@@ -77,8 +77,8 @@ return [
     'email_help' => 'זו היא כתובת הדוא״ל המשמשת לכניסה ולשם גם תשלח מוניקה את התזכורות שלך.',
     'timezone' => 'אזור זמן',
     'temperature_scale' => 'יחידות טמפרטורה',
-    'temperature_scale_fahrenheit' => 'Fahrenheit (°F)',
-    'temperature_scale_celsius' => 'Celsius (°C)',
+    'temperature_scale_fahrenheit' => 'פרנהייט (‎°F)',
+    'temperature_scale_celsius' => 'צלזיוס (‎°C)',
     'layout' => 'פריסה',
     'layout_small' => 'רוחב של 1200 פיקסלים לכל היותר',
     'layout_big' => 'הרוחב המלא של הדפדפן',
