@@ -34,29 +34,29 @@ return [
     'me_choose_placeholder' => 'Scegli te stesso',
 
     'export_title' => 'Esporta i dati del tuo account',
-    'export_be_patient' => 'Click the button to start the export. It might take several minutes to process the export – please be patient and do not spam the button.',
-    'export_title_sql' => 'Export to SQL',
-    'export_sql_explanation' => 'Exporting your data in SQL format allows you to take your data and import it to your own Monica instance. This is only valuable if you do have your own server.',
-    'export_sql_cta' => 'Export to SQL',
-    'export_sql_link_instructions' => 'Note: <a href=":url">read the instructions</a> to learn more about importing this file to your instance.',
-    'export_title_json' => 'Export to Json',
-    'export_submitted' => 'Your export has been submitted, it will be available in a few moment…',
-    'export_json_explanation' => 'Exporting your data in Json format for backup.',
-    'export_json_beta' => 'Json export is in preview mode. Tell us what you think about it:',
-    'export_json_cta' => 'Export to Json',
-    'export_header_type' => 'Type',
-    'export_header_timestamp' => 'Creation date',
-    'export_header_status' => 'Status',
-    'export_header_actions' => 'Actions',
-    'export_last_title' => 'Last exports',
-    'export_empty_title' => 'No exports yet',
-    'export_type_json' => 'Json export',
-    'export_type_sql' => 'SQL export',
-    'export_status_todo' => 'Submitted',
-    'export_status_doing' => 'Doing',
-    'export_status_done' => 'Done',
-    'export_status_failed' => 'Failed',
-    'export_not_done' => 'Download impossible, this export is not done yet.',
+    'export_be_patient' => 'Clicca il pulsante per iniziare l\'esportazione. Potrebbe volerci qualche minuto – ti chiediamo di portare pazienza e non premere il pulsante a ripetizione.',
+    'export_title_sql' => 'Esporta in SQL',
+    'export_sql_explanation' => 'Esportare i dati in formato SQL permette di importarli nella propria istanza di Monica. Questo è da considerare solo se si possiede un server.',
+    'export_sql_cta' => 'Esporta in SQL',
+    'export_sql_link_instructions' => 'Nota: <a href=":url">leggi le istruzioni</a> per capire come importare questo file nella tua istanza di Monica.',
+    'export_title_json' => 'Esporta in Json',
+    'export_submitted' => 'La tua esportazione è stata richiesta, sarà disponibile tra qualche istante…',
+    'export_json_explanation' => 'Esportare i dati in formato Json per il backup.',
+    'export_json_beta' => 'L\'esportazione di Json è in modalità anteprima. Dicci cosa ne pensi:',
+    'export_json_cta' => 'Esporta in Json',
+    'export_header_type' => 'Tipo',
+    'export_header_timestamp' => 'Data di creazione',
+    'export_header_status' => 'Stato',
+    'export_header_actions' => 'Azioni',
+    'export_last_title' => 'Ultime esportazioni',
+    'export_empty_title' => 'Ancora nessuna esportazione',
+    'export_type_json' => 'Esportazione Json',
+    'export_type_sql' => 'Esportazione SQL',
+    'export_status_todo' => 'Inviato',
+    'export_status_doing' => 'Facendo',
+    'export_status_done' => 'Fatto',
+    'export_status_failed' => 'Fallito',
+    'export_not_done' => 'Download impossibile, questa esportazione non è ancora terminata.',
 
     'firstname' => 'Nome',
     'lastname' => 'Cognome',
@@ -85,7 +85,7 @@ return [
     'save' => 'Aggiorna impostazioni',
     'delete_title' => 'Rimuovi il tuo account',
     'delete_desc' => 'Desideri eliminare il tuo profilo? L\'eliminazione è permanente e tutti i tuoi dati saranno eliminati permanentemente. Se hai un abbonamento, sarà annullato immediatamente.',
-    'delete_other_desc' => 'Your data in the main database will be deleted immediately. As described in our privacy policy, we carry out securely encrypted backups of the database every day.  These backups are kept for 30 days after which they are completely deleted. We cannot delete specific data from the backups we hold any earlier than this.  All of your data will be completely deleted no later than 31 days after your account’s deletion.',
+    'delete_other_desc' => 'I tuoi dati nel database principale saranno immediatamente eliminati. Come descritto nella nostra politica della privacy, effettuiamo backup giornalieri, backup crittografati in sicurezza del database, mantenuti per 30 giorni dopo cui sono completamente eliminati. Non possiamo eliminare dati specifici dai backup che manteniamo prima di questo periodo. Tutti i tuoi dati saranno completamente eliminati entro 31 giorni dall\'eliminazione del tuo profilo.',
     'reset_desc' => 'Desideri ripristinare il tuo profilo? Questo rimuoverà tutti i tuoi contatti e tutti i dati a essi associati. Il tuo profilo non sarà eliminato.',
     'reset_title' => 'Reimposta il tuo account',
     'reset_cta' => 'Reimposta il tuo account',
