@@ -44,18 +44,18 @@ return [
     'export_json_explanation' => 'Exporting your data in Json format for backup.',
     'export_json_beta' => 'Json export is in preview mode. Tell us what you think about it:',
     'export_json_cta' => 'Export to Json',
-    'export_header_type' => 'Type',
-    'export_header_timestamp' => 'Creation date',
+    'export_header_type' => 'Soort',
+    'export_header_timestamp' => 'Aanmaak datum',
     'export_header_status' => 'Status',
-    'export_header_actions' => 'Actions',
-    'export_last_title' => 'Last exports',
+    'export_header_actions' => 'Acties',
+    'export_last_title' => 'Laatste exports',
     'export_empty_title' => 'No exports yet',
     'export_type_json' => 'Json export',
     'export_type_sql' => 'SQL export',
-    'export_status_todo' => 'Submitted',
-    'export_status_doing' => 'Doing',
-    'export_status_done' => 'Done',
-    'export_status_failed' => 'Failed',
+    'export_status_todo' => 'Ingediend',
+    'export_status_doing' => 'Bezig',
+    'export_status_done' => 'Gereed',
+    'export_status_failed' => 'Mislukt',
     'export_not_done' => 'Download impossible, this export is not done yet.',
 
     'firstname' => 'Voornaam',
@@ -200,7 +200,7 @@ return [
     'subscriptions_account_current_legacy' => 'Current plan, not selectable anymore:',
     'subscriptions_account_current_paid_plan' => 'Jij gebruikt het :name abonnement. Bedankt voor het aanmelden.',
 
-    'subscriptions_account_next_billing_title' => 'Next bill',
+    'subscriptions_account_next_billing_title' => 'Volgende betaling',
     'subscriptions_account_next_billing' => 'Je abonnement wordt automatisch verlengd op <strong>:date</strong>.',
     'subscriptions_account_bill_monthly' => 'We’ll bill you <strong>:price</strong> for another <strong>month</strong>.',
     'subscriptions_account_bill_annual' => 'We’ll bill you <strong>:price</strong> for another <strong>year</strong>.',
