@@ -140,8 +140,10 @@ return [
 
     'relationship_type_partner' => 'companheiro',
     'relationship_type_partner_female' => 'companheira',
+    'relationship_type_partner_male' => 'significant other',
     'relationship_type_partner_with_name' => 'companheiro de :name',
     'relationship_type_partner_female_with_name' => 'companheira de :name',
+    'relationship_type_partner_male_with_name' => ':name’s significant other',
 
     'relationship_type_spouse' => 'esposo',
     'relationship_type_spouse_female' => 'esposa',
@@ -152,23 +154,31 @@ return [
 
     'relationship_type_date' => 'namorado',
     'relationship_type_date_female' => 'namorada',
+    'relationship_type_date_male' => 'date',
     'relationship_type_date_with_name' => 'namorado de :name',
     'relationship_type_date_female_with_name' => 'namorada de :name',
+    'relationship_type_date_male_with_name' => ':name’s date',
 
     'relationship_type_lover' => 'amante',
     'relationship_type_lover_female' => 'amante',
+    'relationship_type_lover_male' => 'lover',
     'relationship_type_lover_with_name' => 'amante de :name',
     'relationship_type_lover_female_with_name' => 'amante de :name',
+    'relationship_type_lover_male_with_name' => ':name’s lover',
 
     'relationship_type_inlovewith' => 'apaixonado por',
     'relationship_type_inlovewith_female' => 'apaixonada por',
+    'relationship_type_inlovewith_male' => 'in love with',
     'relationship_type_inlovewith_with_name' => 'alguém que :name está apaixonado',
     'relationship_type_inlovewith_female_with_name' => 'alguém que :name está apaixonada',
+    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',
 
     'relationship_type_lovedby' => 'amado por',
     'relationship_type_lovedby_female' => 'amada por',
+    'relationship_type_lovedby_male' => 'loved by',
     'relationship_type_lovedby_with_name' => 'amor secreto de :name',
     'relationship_type_lovedby_female_with_name' => 'amor secreto de :name',
+    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',
 
     'relationship_type_ex' => 'ex-partner',
     'relationship_type_ex_female' => 'ex-namorada',
@@ -228,18 +238,24 @@ return [
 
     'relationship_type_uncle' => 'tio',
     'relationship_type_uncle_female' => 'tia',
+    'relationship_type_uncle_male' => 'uncle',
     'relationship_type_uncle_with_name' => 'tio de :name',
     'relationship_type_uncle_female_with_name' => 'tia de :name',
+    'relationship_type_uncle_male_with_name' => ':name’s uncle',
 
     'relationship_type_nephew' => 'sobrinho',
     'relationship_type_nephew_female' => 'sobrinha',
+    'relationship_type_nephew_male' => 'nephew',
     'relationship_type_nephew_with_name' => 'sobrinho de :name',
     'relationship_type_nephew_female_with_name' => 'sobrinha de :name',
+    'relationship_type_nephew_male_with_name' => ':name’s nephew',
 
     'relationship_type_cousin' => 'primo',
     'relationship_type_cousin_female' => 'prima',
+    'relationship_type_cousin_male' => 'cousin',
     'relationship_type_cousin_with_name' => 'primo de :name',
     'relationship_type_cousin_female_with_name' => 'prima de :name',
+    'relationship_type_cousin_male_with_name' => ':name’s cousin',
 
     'relationship_type_godfather' => 'godparent',
     'relationship_type_godfather_female' => 'madrinha',
@@ -257,38 +273,52 @@ return [
 
     'relationship_type_friend' => 'amigo',
     'relationship_type_friend_female' => 'amiga',
+    'relationship_type_friend_male' => 'amigo',
     'relationship_type_friend_with_name' => 'amigo de :name',
     'relationship_type_friend_female_with_name' => 'amiga de :name',
+    'relationship_type_friend_male_with_name' => ':name’s friend',
 
     'relationship_type_bestfriend' => 'melhor amigo',
     'relationship_type_bestfriend_female' => 'melhor amiga',
+    'relationship_type_bestfriend_male' => 'melhor amigo',
     'relationship_type_bestfriend_with_name' => 'melhor amigo de :name',
     'relationship_type_bestfriend_female_with_name' => 'melhor amiga de :name',
+    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',
 
     'relationship_type_colleague' => 'colega',
     'relationship_type_colleague_female' => 'colega',
+    'relationship_type_colleague_male' => 'colleague',
     'relationship_type_colleague_with_name' => 'colega de :name',
     'relationship_type_colleague_female_with_name' => 'colega de :name',
+    'relationship_type_colleague_male_with_name' => ':name’s colleague',
 
     'relationship_type_boss' => 'chefe',
     'relationship_type_boss_female' => 'chefa',
+    'relationship_type_boss_male' => 'chefe',
     'relationship_type_boss_with_name' => 'chefe de :name',
     'relationship_type_boss_female_with_name' => ':name do chefe',
+    'relationship_type_boss_male_with_name' => ':name’s boss',
 
     'relationship_type_subordinate' => 'funcionário',
     'relationship_type_subordinate_female' => 'funcionário',
+    'relationship_type_subordinate_male' => 'funcionário',
     'relationship_type_subordinate_with_name' => ':name do funcionário',
     'relationship_type_subordinate_female_with_name' => ':name do funcionario',
+    'relationship_type_subordinate_male_with_name' => 'Funcionário do :name’s',
 
     'relationship_type_mentor' => 'mentor',
     'relationship_type_mentor_female' => 'mentora',
+    'relationship_type_mentor_male' => 'mentor',
     'relationship_type_mentor_with_name' => 'mentor de :name',
     'relationship_type_mentor_female_with_name' => 'mentora de :name',
+    'relationship_type_mentor_male_with_name' => 'mentor de :name’s',
 
     'relationship_type_protege' => 'protégé',
     'relationship_type_protege_female' => 'protégé',
+    'relationship_type_protege_male' => 'protégé',
     'relationship_type_protege_with_name' => ':name’s protégé',
     'relationship_type_protege_female_with_name' => ':name’s protégé',
+    'relationship_type_protege_male_with_name' => ':name’s protégé',
 
     'relationship_type_ex_husband' => 'ex-spouse',
     'relationship_type_ex_husband_female' => 'ex wife',
