@@ -14,7 +14,7 @@ return [
     'sidebar_settings_users' => '使用者',
     'sidebar_settings_subscriptions' => '訂閱',
     'sidebar_settings_import' => '匯入資料',
-    'sidebar_settings_tags' => 'Tag management',
+    'sidebar_settings_tags' => '標籤管理',
     'sidebar_settings_api' => 'API',
     'sidebar_settings_dav' => 'Dav 資源',
     'sidebar_settings_security' => '安全',
@@ -35,15 +35,15 @@ return [
 
     'export_title' => '匯出帳戶資料',
     'export_be_patient' => 'Click the button to start the export. It might take several minutes to process the export – please be patient and do not spam the button.',
-    'export_title_sql' => 'Export to SQL',
+    'export_title_sql' => '匯出為 SQL 檔',
     'export_sql_explanation' => 'Exporting your data in SQL format allows you to take your data and import it to your own Monica instance. This is only valuable if you do have your own server.',
-    'export_sql_cta' => 'Export to SQL',
+    'export_sql_cta' => '匯出為 SQL 檔',
     'export_sql_link_instructions' => 'Note: <a href=":url">read the instructions</a> to learn more about importing this file to your instance.',
-    'export_title_json' => 'Export to Json',
+    'export_title_json' => '匯出為 JSON 檔',
     'export_submitted' => 'Your export has been submitted, it will be available in a few moment…',
     'export_json_explanation' => 'Exporting your data in Json format for backup.',
     'export_json_beta' => 'Json export is in preview mode. Tell us what you think about it:',
-    'export_json_cta' => 'Export to Json',
+    'export_json_cta' => '匯出為 JSON 檔',
     'export_header_type' => 'Type',
     'export_header_timestamp' => 'Creation date',
     'export_header_status' => 'Status',
@@ -56,35 +56,35 @@ return [
     'export_status_doing' => 'Doing',
     'export_status_done' => 'Done',
     'export_status_failed' => 'Failed',
-    'export_not_done' => 'Download impossible, this export is not done yet.',
+    'export_not_done' => '正在匯出中，尚無法下載。',
 
     'firstname' => '名',
     'lastname' => '姓氏',
     'name_order' => '名稱順序',
-    'name_order_firstname_lastname' => '<First name> <Last name> – John Doe',
-    'name_order_lastname_firstname' => '<Last name> <First name> – Doe John',
-    'name_order_firstname_lastname_nickname' => '<First name> <Last name> (<Nickname>) – John Doe (Rambo)',
-    'name_order_firstname_nickname_lastname' => '<First name> (<Nickname>) <Last name> – John (Rambo) Doe',
-    'name_order_lastname_firstname_nickname' => '<Last name> <First name> (<Nickname>) – Doe John (Rambo)',
-    'name_order_lastname_nickname_firstname' => '<Last name> (<Nickname>) <First name> – Doe (Rambo) John',
-    'name_order_nickname_firstname_lastname' => '<Nickname> (<First name> <Last name>) – Rambo (John Doe)',
-    'name_order_nickname_lastname_firstname' => '<Nickname> (<Last name> <First name>) – Rambo (Doe John)',
-    'name_order_nickname' => '<Nickname> – Rambo',
+    'name_order_firstname_lastname' => '<名> <姓> - 小明 王',
+    'name_order_lastname_firstname' => '<姓> <名> - 王 小明',
+    'name_order_firstname_lastname_nickname' => '<名> <姓> (<暱稱>) - 小明 王 (小黑)',
+    'name_order_firstname_nickname_lastname' => '<名> (<暱稱>) <姓> - 小明 (小黑) 王',
+    'name_order_lastname_firstname_nickname' => '<姓> <名> (<暱稱>) - 王 小明 (小黑)',
+    'name_order_lastname_nickname_firstname' => '<姓> (<暱稱>) <名> - 王 (小黑) 小明',
+    'name_order_nickname_firstname_lastname' => '<暱稱> (<名> <姓>) - 小黑 (小明 王)',
+    'name_order_nickname_lastname_firstname' => '<暱稱> (<姓> <名>) - 小黑 (王 小明)',
+    'name_order_nickname' => '<暱稱> - 小黑',
     'currency' => '貨幣',
     'name' => '您的姓名: :name',
     'email' => '電子郵件地址',
     'email_placeholder' => '輸入電子郵箱',
-    'email_help' => 'This is the email used to login, and this is where Monica will send your reminders.',
+    'email_help' => '這是用於登入的電子郵件, 同時也用來接收您的提醒。',
     'timezone' => '時區',
     'temperature_scale' => '溫度單位',
-    'temperature_scale_fahrenheit' => 'Fahrenheit (°F)',
-    'temperature_scale_celsius' => 'Celsius (°C)',
+    'temperature_scale_fahrenheit' => '華氏 (°F)',
+    'temperature_scale_celsius' => '攝氏 (°C)',
     'layout' => '佈局',
     'layout_small' => '最大1200畫素寬',
     'layout_big' => '瀏覽器的全寬度',
     'save' => '更新偏好',
     'delete_title' => '刪除您的帳戶',
-    'delete_desc' => 'Do you wish to delete your account? Deletion is permanent and all of your data will be erased permanently. If you have a subscription, it will be cancelled immediately.',
+    'delete_desc' => '是否刪除帳戶？您的資料將永遠刪除。若您是付費用戶，將立即退訂。',
     'delete_other_desc' => 'Your data in the main database will be deleted immediately. As described in our privacy policy, we carry out securely encrypted backups of the database every day.  These backups are kept for 30 days after which they are completely deleted. We cannot delete specific data from the backups we hold any earlier than this.  All of your data will be completely deleted no later than 31 days after your account’s deletion.',
     'reset_desc' => 'Do you wish to reset your account? This will remove all your contacts, and all of the data associated with them. Your account will not be deleted.',
     'reset_title' => '刪除您的帳戶',
@@ -99,48 +99,48 @@ return [
     'locale_ar' => '阿拉伯文',
     'locale_cs' => '捷克文',
     'locale_de' => '德文',
-    'locale_el' => 'Greek',
+    'locale_el' => '希臘語',
     'locale_en' => '英文',
     'locale_en-GB' => '英語 (英國)',
     'locale_es' => '西班牙文',
     'locale_fr' => '法文',
     'locale_he' => '希伯來文',
     'locale_hr' => '克羅埃西亞文',
-    'locale_id' => 'Indonesian',
+    'locale_id' => '印尼語',
     'locale_it' => '義大利文',
-    'locale_ja' => 'Japanese',
+    'locale_ja' => '日語',
     'locale_nl' => '荷蘭文',
     'locale_pt' => '葡萄牙文',
     'locale_pt-BR' => 'Portuguese, Brazil',
     'locale_ru' => '俄文',
-    'locale_sv' => 'Swedish',
-    'locale_vi' => 'Vietnamese',
+    'locale_sv' => '瑞典語',
+    'locale_vi' => '越南語',
     'locale_zh' => '簡體中文',
     'locale_zh-TW' => '繁體中文（台灣）',
     'locale_tr' => '土耳其文',
 
     'security_title' => '安全',
     'security_help' => '更改您的帳戶的安全選項。',
-    'password_change' => 'Change your password',
+    'password_change' => '變更您的密碼',
     'password_current' => '當前密碼',
     'password_current_placeholder' => '輸入當前密碼',
     'password_new1' => '新密碼',
-    'password_new1_placeholder' => 'Enter your new password',
-    'password_new2' => 'Confirm your new password',
-    'password_new2_placeholder' => 'Retype your new password',
+    'password_new1_placeholder' => '請輸入新密碼',
+    'password_new2' => '確認您的新密碼',
+    'password_new2_placeholder' => '重新輸入新密碼',
     'password_btn' => '更改密碼',
     '2fa_title' => '雙重驗證',
     '2fa_otp_title' => '用於二次驗證的App',
     '2fa_enable_title' => '啟用二次驗證',
-    '2fa_enable_description' => 'Enable Two Factor Authentication to increase the security of your account.',
-    '2fa_enable_otp' => 'Open up your Two Factor Authentication mobile app and scan the following QR barcode:',
-    '2fa_enable_otp_help' => 'If your Two Factor Authentication mobile app does not support QR barcodes, enter in the following code:',
-    '2fa_enable_otp_validate' => 'Please validate the new device you’ve just set up:',
+    '2fa_enable_description' => '啟用雙重身份驗證以提高帳戶的安全性。',
+    '2fa_enable_otp' => '開啟您的雙重認證移動應用程式, 並掃描以下 QR 條碼:',
+    '2fa_enable_otp_help' => '如果您的雙重認證移動應用程式不支援 QR 條碼, 請在下面的程式碼中輸入:',
+    '2fa_enable_otp_validate' => '請驗證您剛設定的新裝置:',
     '2fa_enable_success' => '雙重認證已啟用',
     '2fa_enable_error' => '嘗試啟用雙重身份驗證時出錯',
     '2fa_enable_error_already_set' => '二次驗證已啟用',
     '2fa_disable_title' => '關閉雙重身份驗證',
-    '2fa_disable_description' => 'Disable Two Factor Authentication for your account. Be careful, your account will be much less secure!',
+    '2fa_disable_description' => '停用雙重素身份驗證。注意！您的帳戶將不再安全！',
     '2fa_disable_success' => '雙重身份認證已禁用',
     '2fa_disable_error' => '嘗試禁用雙重身份驗證時出錯',
 
@@ -165,10 +165,10 @@ return [
     'recovery_copy_help' => '複製到您的剪貼簿',
     'recovery_help_intro' => '以下是您的恢復程式碼:',
     'recovery_help_information' => '您可以使用每個恢復程式碼一次。',
-    'recovery_clipboard' => 'Codes copied to the clipboard.',
-    'recovery_generate' => 'Generate new codes…',
-    'recovery_generate_help' => 'Generating new codes will invalidate previously generated codes.',
-    'recovery_already_used_help' => 'This code has already been used.',
+    'recovery_clipboard' => '已複製到剪貼簿.',
+    'recovery_generate' => '正在產生中...',
+    'recovery_generate_help' => '請注意，重新產生新程式碼將使以前的程式碼失效.',
+    'recovery_already_used_help' => '此程式碼已被使用。',
 
     'users_list_title' => '可以訪問您的帳戶的使用者',
     'users_list_add_user' => '邀請新使用者',
@@ -181,8 +181,8 @@ return [
     'users_blank_add_title' => '你想邀請別人嗎？',
     'users_blank_description' => '此人將具有您擁有的相同訪問許可權, 並且可以新增、編輯或刪除聯絡人資訊。',
     'users_blank_cta' => '邀請他人加入',
-    'users_add_title' => 'Invite a new user to your account by email',
-    'users_add_description' => 'This person will have the same access as you do, including inviting or deleting other users, including you. Make sure you trust this person before giving them access.',
+    'users_add_title' => '透過 Email 邀請新的用戶',
+    'users_add_description' => '新的用戶權限將和您一樣，可以邀請或刪除其他用戶(包含您)。請再次確認您信任他/她後再授予權限。',
     'users_add_email_field' => '輸入您要邀請的人的電子郵件',
     'users_add_confirmation' => 'I confirm that I want to invite this user to my account. I understand that this person will have access to ALL of my data and see exactly what I see.',
     'users_add_cta' => '通過電子郵件邀請使用者',
@@ -300,11 +300,11 @@ return [
     'import_upload_rule_instructions' => 'Export instructions for <a href=":url1" target="_blank" rel="noopener noreferrer">macOS Contacts.app</a> and <a href=":url2" target="_blank" rel="noopener noreferrer">Google Contacts</a>.',
     'import_upload_rule_multiple' => 'If your contacts have multiple email addresses or phone numbers, only the first entry will be saved.',
     'import_upload_rule_limit' => 'Files are limited to 10 MB.',
-    'import_upload_rule_time' => 'It might take up to a minute to upload the contacts and process them. Please be patient.',
-    'import_upload_rule_cant_revert' => 'Please make sure data is accurate before uploading, as you can’t undo the upload.',
+    'import_upload_rule_time' => '上傳聯絡人有時需要幾分鐘的時間，請耐心等待。',
+    'import_upload_rule_cant_revert' => '請確認您上傳的資料是正確的，一旦上傳就無法撤銷。',
     'import_upload_form_file' => '你的 <code>.vcf</code> 或 <code>. vCard</code> 檔案:',
     'import_upload_behaviour' => '匯入偏好:',
-    'import_upload_behaviour_add' => 'Add new contacts and skip existing',
+    'import_upload_behaviour_add' => '新增新聯絡人，並跳過已存在的聯絡人',
     'import_upload_behaviour_replace' => '替換現有條目',
     'import_upload_behaviour_help' => 'Replacing will replace all data found in the vCard, but will keep existing contact fields.',
     'import_report_title' => '匯入報表',
@@ -458,7 +458,7 @@ return [
     'personalization_activity_type_modal_delete_error' => '我們無法找到這個活動',
     'personalization_activity_type_category_modal_delete_error' => '我們無法找到這個活動分類',
 
-    'personalization_life_event_category_title' => 'Life event categories',
+    'personalization_life_event_category_title' => '生活事件分類',
     'personalization_live_event_category_table_name' => 'Name',
     'personalization_life_event_category_description' => 'A life event can have a type and a category. Your account comes with a set of predefined categories and types by default, but you can customize life event types here.',
     'personalization_live_event_category_table_actions' => 'Actions',
@@ -504,15 +504,15 @@ return [
     'personalization_life_event_type_quit_a_habit' => '戒掉一個習慣',
     'personalization_life_event_type_new_eating_habits' => '新的飲食習慣',
     'personalization_life_event_type_weight_loss' => '減肥',
-    'personalization_life_event_type_wear_glass_or_contact' => 'Started wearing glasses or contacts',
-    'personalization_life_event_type_broken_bone' => 'Broke a bone',
-    'personalization_life_event_type_removed_braces' => 'Had braces removed',
-    'personalization_life_event_type_surgery' => 'Had surgery',
-    'personalization_life_event_type_dentist' => 'Had dental treatment',
-    'personalization_life_event_type_new_sport' => 'Started playing a new sport',
-    'personalization_life_event_type_new_hobby' => 'Took up a new hobby',
+    'personalization_life_event_type_wear_glass_or_contact' => '開始戴眼鏡或隱形眼鏡',
+    'personalization_life_event_type_broken_bone' => '骨折',
+    'personalization_life_event_type_removed_braces' => '摘掉牙套',
+    'personalization_life_event_type_surgery' => '動過手術',
+    'personalization_life_event_type_dentist' => '做過牙科治療',
+    'personalization_life_event_type_new_sport' => '開始參與一項新的運動',
+    'personalization_life_event_type_new_hobby' => '開始一項新的興趣',
     'personalization_life_event_type_new_instrument' => 'Started learning a new instrument',
-    'personalization_life_event_type_new_language' => 'Started learning a new language',
+    'personalization_life_event_type_new_language' => '開始學一門新的外語',
     'personalization_life_event_type_tattoo_or_piercing' => '紋身或耳洞',
     'personalization_life_event_type_new_license' => '新駕照',
     'personalization_life_event_type_travel' => '旅行',
@@ -522,7 +522,7 @@ return [
     'personalization_life_event_type_first_kiss' => '初吻',
 
     'storage_title' => '儲存空間',
-    'storage_account_info' => 'Your account limit is :accountLimit MB. Your current usage is :currentAccountSize MB (about :percentUsage%).',
+    'storage_account_info' => '您的賬戶大小為: :accountLimit Mb /  您目前已使用: :currentAccountSize Mb (約 :percentUsage%).',
     'storage_upgrade_notice' => '升級您的帳戶, 以便上傳文件和照片。',
     'storage_description' => '在這裡, 您可以看到上傳的有關您的聯絡人的所有文件和照片。',
 
