@@ -35,7 +35,7 @@ return [
 
     'export_title' => '导出帐户数据',
     'export_be_patient' => 'Click the button to start the export. It might take several minutes to process the export – please be patient and do not spam the button.',
-    'export_title_sql' => 'Export to SQL',
+    'export_title_sql' => '导出未SQL文件',
     'export_sql_explanation' => 'Exporting your data in SQL format allows you to take your data and import it to your own Monica instance. This is only valuable if you do have your own server.',
     'export_sql_cta' => 'Export to SQL',
     'export_sql_link_instructions' => 'Note: <a href=":url">read the instructions</a> to learn more about importing this file to your instance.',
